An S4 class to represent a neural network decoder, used for emulating spatial priors. The class includes parameters for input and output weight matrices and biases, as well as region identifiers.
GEOIDA character vector of region or area identifiers.
W_inAn array representing the input weight matrix of the decoder.
B_inAn array representing the input bias vector of the decoder.
W_outAn array representing the output weight matrix of the decoder.
B_outAn array representing the output bias vector of the decoder.