An S4 class to store results from the Variational Gaussian Markov Small Area Estimation with Fay-Herriot model (VGMSFH). This class holds the posterior samples for various model components as well as the original direct estimates.
model_nameCharacter. The name of the trained VAE model.
direct_estimateArray. Direct estimates of parameters.
yhat_samplesArray. Posterior samples of the estimated parameters.
phi_samplesArray. Posterior samples of the estimated spatial random effects.
beta_samplesArray. Posterior samples of the fixed effect coefficients.
other_samplesList. List of posterior samples of other parameters in the VGMSFH model.