Learn R Programming

vmsae (version 0.1.2)

install_environment: Install python environment.

Description

This function creates the vmsae python environment and installs required packages.

Usage

install_environment(envname = "vmsae", use_gpu = FALSE)

Value

No return value, called for side effects

Arguments

envname

Character. The name of the Python environment to create or update. Default is "vmsae".

use_gpu

Boolean. An indicator for whether to install packages with GPU support. Default is FALSE.

Examples

Run this code
if (FALSE) {
library(vmsae)
# this function is time consuming for the first run
install_environment()          # Install into default "vmsae" environment


# this step is time consuming for the first run
install_environment("custom")  # Install into a custom-named environment
}

Run the code above in your browser using DataLab