if (FALSE) {
library(vmsae)
# this function is time consuming for the first run
install_environment() # Install into default "vmsae" environment
# this step is time consuming for the first run
install_environment("custom") # Install into a custom-named environment
}
Run the code above in your browser using DataLab