if (FALSE) {
library(vmsae)
# this function is time consuming for the first run
install_environment()
load_environment() # Load default "vmsae" environment
# this function is time consuming for the first run
install_environment("custom")
load_environment("custom") # Load custom virtual environment
load_environment("custom", is_conda = TRUE) # Load custom conda environment
}
Run the code above in your browser using DataLab